@@ -2,8 +2,7 @@ from flask import Flask
 from flask.testing import FlaskClient
 
 from flask_autocrud import AutoCrud
-
-from .models import db
+from tests.models import db
 
 
 def create_app(m=None, conf=None):
@@ -12,6 +11,7 @@ def create_app(m=None, conf=None):
             return self.open(url, method='FETCH', *args, **kwargs)
 
     _app = Flask(__name__)
+    _app.config['DEBUG'] = True
     _app.config['SQLALCHEMY_DATABASE_URI'] = 'sqlite+pysqlite:///tests/db.sqlite3'
     _app.config['SQLALCHEMY_TRACK_MODIFICATIONS'] = False
     _app.config['ERROR_FORCE_CONTENT_TYPE'] = False
